# This file was auto-generated by Fern from our API Definition.

from ..core.api_error import ApiError
from ..types.parent_folder_error import ParentFolderError


class BadRequestError(ApiError):
    def __init__(self, body: ParentFolderError):
        super().__init__(status_code=400, body=body)
